Module handler

Module handler 

Handlers define what to do with received column definition and row packets.

Structs

CollectHandler
Handler that collects typed rows.
DropHandler
A handler that discards all results.
FirstRowHandler
Handler that collects only the first row.
ForEachHandler
Handler that calls a closure for each row.
ForEachRefHandler
A handler that calls a closure for each row using zero-copy RefFromRow.

Traits

AsyncMessageHandler
Handler for asynchronous messages from the server.
ExtendedHandler
Handler for extended query protocol.
SimpleHandler
Handler for simple query protocol.