ForEachRefHandler

Struct ForEachRefHandler 

pub struct ForEachRefHandler<Row, F> { /* private fields */ }
A handler that calls a closure for each row using zero-copy RefFromRow.

Unlike ForEachHandler, this handler uses RefFromRow to decode rows as zero-copy references into the buffer. The closure receives a reference to the decoded struct.

Requirements

  • The row type must implement RefFromRow
  • All struct fields must use LengthPrefixed<T> with big-endian types
  • All columns must be NOT NULL

Implementations

Source

impl<Row, F> ForEachRefHandler<Row, F>

pub fn new(f: F) -> Self