IntoStatement

Trait IntoStatement 

pub trait IntoStatement: Sealed {
    // Required method
    fn statement_ref(&self) -> StatementRef<'_>;
}
Sealed trait for types that can be used as statement references in exec_* methods.

This trait is sealed and cannot be implemented outside this crate.

Required Methods

fn statement_ref(&self) -> StatementRef<'_>

Return a StatementRef discriminating raw SQL from a prepared statement.

Implementations on Foreign Types

Source

impl IntoStatement for &&str

Source

impl IntoStatement for &str

Source

impl IntoStatement for str

Implementors